@@ -1,6 +1,8 @@
-#
 # basic_tests.py -- Basic unit tests for Terminado
-#
+
+# Copyright (c) Jupyter Development Team
+# Copyright (c) 2014, Ramalingam Saravanan <sarava@sarava.net>
+# Distributed under the terms of the Simplified BSD License.
 
 from __future__ import absolute_import, print_function
 
@@ -15,6 +17,8 @@ import datetime
 import logging
 import json
 import os
+import re
+
 
 #
 # The timeout we use to assume no more messages are coming
@@ -81,7 +85,11 @@ class TestTermClient(object):
         yield self.read_stdout()                          # Clear out any pending
         self.write_stdin("echo $$\r")
         (stdout, extra) = yield self.read_stdout()
-        pid = int(stdout.split('\n')[1])
+        if os.name == 'nt':
+            match = re.search(r'echo \$\$\x1b\[0K\r\n(\d+)', stdout)
+            pid = int(match.groups()[0])
+        else:
+            pid = int(stdout.split('\n')[1])
         raise tornado.gen.Return(pid)
 
     def close(self):
@@ -162,7 +170,10 @@ class CommonTests(TermTestCase):
             yield tm.read_all_msg()
             tm.write_stdin("whoami\n")
             (stdout, other) = yield tm.read_stdout()
-            assert stdout.startswith('who')
+            if os.name == 'nt':
+                assert 'whoami' in stdout
+            else:
+                assert stdout.startswith('who')
             assert other == []
             tm.close()
 
